#
# spec file for package sat4j
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define eclipse_base %{_libdir}/eclipse
# We want the version to match that shipped in Eclipse's Orbit project
%define qualifier 20181123
Name:           sat4j
Version:        2.3.5
Release:        4.3
Summary:        A library of SAT solvers written in Java
License:        EPL-1.0 AND LGPL-2.0-only
Group:          Development/Libraries/Java
URL:            https://www.sat4j.org/
Source0:        %{name}-%{version}.tar.xz
Patch0:         sat4j-sourcetarget.patch
Patch1:         sat4j-manifest.patch
BuildRequires:  ant
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
Requires:       java >= 1.8
BuildArch:      noarch

%description
The aim of the SAT4J library is to provide an efficient library of SAT
solvers in Java. The SAT4J library targets first users of SAT "black
boxes", those willing to embed SAT technologies into their application
without worrying about the details.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1

%pom_xpath_remove "pom:dependency[pom:type[text()='test-jar']]" org.sat4j.pb

%build
ant \
    -Dbuild.compiler=modern -Drelease=%{version} \
	-DBUILD_DATE=%{qualifier} -Dsource=1.8 -Dtarget=1.8 p2

%install
#jar
install -d -m 755 %{buildroot}%{_javadir}
install -m 0644 dist/%{version}/org.sat4j.core.jar %{buildroot}%{_javadir}/org.sat4j.core.jar
install -m 0644 dist/%{version}/org.sat4j.pb.jar   %{buildroot}%{_javadir}/org.sat4j.pb.jar
#pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} org.sat4j.core/pom.xml %{buildroot}%{_mavenpomdir}/org.sat4j.core.pom
%add_maven_depmap org.sat4j.core.pom org.sat4j.core.jar
%{mvn_install_pom} org.sat4j.pb/pom.xml %{buildroot}%{_mavenpomdir}/org.sat4j.pb.pom
%add_maven_depmap org.sat4j.pb.pom org.sat4j.pb.jar

%files -f .mfiles

%changelog
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Sun May 28 2023 Fridrich Strba <fstrba@suse.com>
- Distribute the maven metadata, so that the artifacts can be used
  by maven builds.
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Specify source and target levels 1.8
* Fri Nov 23 2018 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.3.5
- Modified patch:
  * sat4j-sourcetarget.patch
    + rediff to changed context and add utf-8 encoding for build
* Thu Nov 22 2018 Fridrich Strba <fstrba@suse.com>
- Buildrequire javapackages-local in order to generate the osgi
  provides.
* Wed Sep 20 2017 fstrba@suse.com
- Added patches:
  * sat4j-sourcetarget.patch
    + make the java source and target level consistent with what
    is specified on command-line
    + specify the UTF-8 encoding of the source files
  * sat4j-manifest.patch
    + fix rpmlint warning about Class-path in manifest
  + remove all mentions of Class-path from MANIFEST.MF files
* Sun May 21 2017 tchvatal@suse.com
- Remove un-needed dependencies
* Fri Jun 27 2014 tchvatal@suse.com
- Fix build on SLE11
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Thu Oct 18 2012 p.drouand@gmail.com
- Update to 2.3.2 version :
  * Bug [SAT-55] Fix memory leak in case of repeated use of Sat4j in an application
  * Bug [SAT-60] ClassCastException when a class implements Propagatable but not Constr watches a conflicting literal
  * Improvement [SAT-38] Investigate usage of plain CNF rather than custom cardinality of PB constraints
  * Improvement [SAT-59] Use package-info.java instead of package.html for package JavaDoc
  * Improvement [SAT-67] Concurrent calls to isSatisfiable
  * New Feature [SAT-56] Allow the end user to visualize the search of the solvers
  * New Feature [SAT-63] Make Java 1.5 binaries instead of 1.4
  * New Feature [SAT-71] Add statistics in ManyCore solvers on the solvers that answers
  * Sub-task    [SAT-51] Allow usage of Lower Bounding on Sat4j PB command line
* Mon Jun 18 2012 mvyskocil@suse.cz
- fix a build with jdk7 (-Dtarget)
* Wed Jul 29 2009 mvyskocil@suse.cz
- Don't use release date to make number of Factory rebuilds smaller
* Tue Jun  2 2009 mvyskocil@suse.cz
- Initial packaging of sat4j 2.0.3 in openSUSE
